@@ -7,19 +7,24 @@
 
 #include "account.h"
 #include "account_debug.h"
+#include "dbushelpers.h"
 #include "userinfodialog.h"
 #include "utils.h"
 
+#include <QDBusConnection>
+
 AccountPortal::AccountPortal(QObject *parent)
     : QDBusAbstractAdaptor(parent)
 {
 }
 
-uint AccountPortal::GetUserInformation(const QDBusObjectPath &handle,
+void AccountPortal::GetUserInformation(const QDBusObjectPath &handle,
                                        const QString &app_id,
                                        const QString &parent_window,
                                        const QVariantMap &options,
-                                       QVariantMap &results)
+                                       const QDBusMessage &message,
+                                       [[maybe_unused]] uint &replyResponse,
+                                       [[maybe_unused]] QVariantMap &replyResults)
 {
     qCDebug(XdgDesktopPortalKdeAccount) << "GetUserInformation called with parameters:";
     qCDebug(XdgDesktopPortalKdeAccount) << "    handle: " << handle.path();
@@ -33,19 +38,17 @@ uint AccountPortal::GetUserInformation(const QDBusObjectPath &handle,
         reason = options.value(QStringLiteral("reason")).toString();
     }
 
-    UserInfoDialog *userInfoDialog = new UserInfoDialog(reason);
+    UserInfoDialog *userInfoDialog = new UserInfoDialog(reason, app_id);
     Utils::setParentWindow(userInfoDialog->windowHandle(), parent_window);
 
-    int result = userInfoDialog->exec();
-
-    if (result) {
-        results.insert(QStringLiteral("id"), userInfoDialog->id());
-        results.insert(QStringLiteral("name"), userInfoDialog->name());
-        const QString image = userInfoDialog->image();
-        results.insert(QStringLiteral("image"), image.isEmpty() ? QStringLiteral("file://") : image);
-    }
-
-    userInfoDialog->deleteLater();
-
-    return !result;
+    delayReply(message, userInfoDialog, this, [message, userInfoDialog](DialogResult result) {
+        QVariantMap results;
+        if (result == DialogResult::Accepted) {
+            results.insert(QStringLiteral("id"), userInfoDialog->id());
+            results.insert(QStringLiteral("name"), userInfoDialog->name());
+            const QString image = userInfoDialog->image();
+            results.insert(QStringLiteral("image"), image.isEmpty() ? QStringLiteral("file://") : image);
+        }
+        return QVariantList{PortalResponse::fromDialogResult(result), results};
+    });
 }
