@@ -24,6 +24,9 @@ class FileChooserQmlCallback : public QObject
 public:
     FileChooserQmlCallback(QObject *parent = nullptr);
 
+    void reset();
+    void requestReloadWindow();
+
     QString title() const;
     void setTitle(const QString &title);
 
@@ -65,6 +68,8 @@ Q_SIGNALS:
     void acceptLabelChanged();
     void selectFolderChanged();
 
+    void reloadWindow();
+
 private:
     QString m_title;
     bool m_selectMultiple;
