@@ -76,11 +76,13 @@ ScreenshotPortal::~ScreenshotPortal()
 {
 }
 
-uint ScreenshotPortal::Screenshot(const QDBusObjectPath &handle,
+void ScreenshotPortal::Screenshot(const QDBusObjectPath &handle,
                                   const QString &app_id,
                                   const QString &parent_window,
                                   const QVariantMap &options,
-                                  QVariantMap &results)
+                                  const QDBusMessage &message,
+                                  uint &replyResponse,
+                                  QVariantMap &replyResults)
 {
     qCDebug(XdgDesktopPortalKdeScreenshot) << "Screenshot called with parameters:";
     qCDebug(XdgDesktopPortalKdeScreenshot) << "    handle: " << handle.path();
@@ -96,33 +98,36 @@ uint ScreenshotPortal::Screenshot(const QDBusObjectPath &handle,
     screenshotDialog->windowHandle()->setModality(modal ? Qt::WindowModal : Qt::NonModal);
 
     const bool interactive = options.value(QStringLiteral("interactive"), false).toBool();
+
+    auto createReply = [](const QImage &screenshot) -> std::pair<PortalResponse::Response, QVariantMap> {
+        if (screenshot.isNull()) {
+            return {PortalResponse::OtherError, {}};
+        }
+        const QString filename = QStringLiteral("%1/Screenshot_%2.png") //
+                                     .arg(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation),
+                                          QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd_hhmmss")));
+        if (!screenshot.save(filename, "PNG")) {
+            return {PortalResponse::OtherError, {}};
+        }
+        return {PortalResponse::Success, {{QStringLiteral("uri"), QUrl::fromLocalFile(filename).toString(QUrl::FullyEncoded)}}};
+    };
+
     if (!interactive) {
+        qDebug() << "take non interactive";
         screenshotDialog->takeScreenshotNonInteractive();
-    } else {
-        screenshotDialog->exec();
-    }
-
-    const QImage screenshot = screenshotDialog->image();
-
-    if (screenshotDialog) {
+        std::tie(replyResponse, replyResults) = createReply(screenshotDialog->image());
         screenshotDialog->deleteLater();
+        return;
     }
 
-    if (screenshot.isNull()) {
-        return 1;
-    }
-
-    const QString filename =
-        QStringLiteral("%1/Screenshot_%2.png") //
-            .arg(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation), QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd_hhmmss")));
-
-    if (!screenshot.save(filename, "PNG")) {
-        return 1;
-    }
-
-    results.insert(QStringLiteral("uri"), QUrl::fromLocalFile(filename).toString(QUrl::FullyEncoded));
-
-    return 0;
+    delayReply(message, screenshotDialog.get(), this, [screenshotDialog, createReply](DialogResult dialogResult) {
+        auto response = PortalResponse::fromDialogResult(dialogResult);
+        QVariantMap results;
+        if (dialogResult == DialogResult::Accepted) {
+            std::tie(response, results) = createReply(screenshotDialog->image());
+        }
+        return QVariantList{response, results};
+    });
 }
 
 uint ScreenshotPortal::PickColor(const QDBusObjectPath &handle,
@@ -150,8 +155,8 @@ uint ScreenshotPortal::PickColor(const QDBusObjectPath &handle,
         color.blue = selectedColor.blueF();
 
         results.insert(QStringLiteral("color"), QVariant::fromValue<ScreenshotPortal::ColorRGB>(color));
-        return 0;
+        return PortalResponse::Success;
     }
 
-    return 1;
+    return PortalResponse::Cancelled;
 }
